is_minimally_connected

Function is_minimally_connected 

async fn is_minimally_connected(state: Arc<AppState>) -> bool
Check if the node has minimal network connectivity.

Returns true if the network health is Orange, Yellow, or Green. Returns false if the network health is Unknown or Red.